==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/apps/files_external/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." => "La requête de récupération des jetons d’authentification a échoué. Veuillez vérifier votre App-Key Dropbox ainsi que le mot de passe.",
"Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." => "La requête d’accès aux jetons d’authentification a échoué. Veuillez vérifier votre App-Key Dropbox ainsi que le mot de passe.",
"Please provide a valid Dropbox app key and secret." => "Veuillez fournir une clé d'application (app key) ainsi qu'un mot de passe valides.",
"Step 1 failed. Exception: %s" => "L’étape 1 a échoué. Erreur: %s",
"Step 2 failed. Exception: %s" => "L’étape 2 a échoué. Erreur: %s",
"External storage" => "Stockage externe",
"Local" => "Local",
"Location" => "Emplacement",
"Amazon S3" => "Amazon S3",
"Key" => "Clé",
"Secret" => "Secret",
"Bucket" => "Seau",
"Amazon S3 and compliant" => "Compatible avec Amazon S3",
"Access Key" => "Clé d'accès",
"Secret Key" => "Clé secrète",
"Hostname (optional)" => "Nom machine (optionnel)",
"Port (optional)" => "Port (optionnel)",
"Region (optional)" => "Région (facultatif)",
"Enable SSL" => "Activer SSL",
"Enable Path Style" => "Activer le style de chemin",
"App key" => "Clé App",
"App secret" => "Secret de l'application",
"Host" => "Hôte",
"Username" => "Nom d'utilisateur",
"Password" => "Mot de passe",
"Root" => "Root",
"Secure ftps://" => "Sécuriser via ftps://",
"Client ID" => "ID Client",
"Client secret" => "Secret client",
"OpenStack Object Storage" => "Object de Stockage OpenStack",
"Username (required)" => "Nom d'utilisation (requis)",
"Bucket (required)" => "Bucket (requis)",
"Region (optional for OpenStack Object Storage)" => "Region (optionnel pour Object de Stockage OpenStack)",
"API Key (required for Rackspace Cloud Files)" => "Clé API (requis pour Rackspace Cloud Files)",
"Tenantname (required for OpenStack Object Storage)" => "Nom du locataire (requis pour le stockage OpenStack)",
"Password (required for OpenStack Object Storage)" => "Mot de passe (requis pour OpenStack Object Storage)",
"Service Name (required for OpenStack Object Storage)" => "Nom du service (requit pour le stockage OpenStack)",
"URL of identity endpoint (required for OpenStack Object Storage)" => "URL du point d'accès d'identité (requis pour le stockage OpenStack)",
"Timeout of HTTP requests in seconds (optional)" => "Temps maximal de requête HTTP en seconde (facultatif)",
"Share" => "Partager",
"SMB / CIFS using OC login" => "SMB / CIFS utilise le nom d'utilisateur OC",
"Username as share" => "Nom d'utilisateur du partage",
"URL" => "URL",
"Secure https://" => "Sécurisation https://",
"Remote subfolder" => "Sous-dossier distant",
"Access granted" => "Accès autorisé",
"Error configuring Dropbox storage" => "Erreur lors de la configuration du support de stockage Dropbox",
"Grant access" => "Autoriser l'accès",
"Error configuring Google Drive storage" => "Erreur lors de la configuration du support de stockage Google Drive",
"Personal" => "Personnel",
"System" => "Système",
"Saved" => "Sauvegarder",
"<b>Note:</b> " => "<b>Attention :</b>",
" and " => "et",
"<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." => "<b>Attention :</b> Le support de cURL de PHP n'est pas activé ou installé. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
"<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." => "<b>Attention : </b> Le support FTP de PHP n'est pas activé ou installé. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
"<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." => "<b>Attention : </b> \"%s\" n'est pas installé. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
"You don't have any external storages" => "Vous n'avez pas de support de stockage externe",
"Name" => "Nom",
"Storage type" => "Type de support de stockage",
"Scope" => "Portée",
"External Storage" => "Stockage externe",
"Folder name" => "Nom du dossier",
"Configuration" => "Configuration",
"Options" => "Options",
"Available for" => "Disponible pour",
"Add storage" => "Ajouter un support de stockage",
"No user or group" => "Aucun utilisateur ou groupe",
"All Users" => "Tous les utilisateurs",
"Groups" => "Groupes",
"Users" => "Utilisateurs",
"Delete" => "Supprimer",
"Enable User External Storage" => "Activer le stockage externe pour les utilisateurs",
"Allow users to mount the following external storage" => "Autorise les utilisateurs à monter les stockage externes suivants",
"SSL root certificates" => "Certificats racine SSL",
"Import Root Certificate" => "Importer un certificat racine"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/apps/files_external/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." => "La récupération des jetons d’authentification a échoué. Veuillez vérifier votre clé d'application Dropbox ainsi que le mot de passe.",
"Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." => "La requête d’accès aux jetons d’authentification a échoué. Veuillez vérifier votre App-Key Dropbox ainsi que le mot de passe.",
"Please provide a valid Dropbox app key and secret." => "Veuillez fournir une clé d'application (app key) ainsi qu'un mot de passe valides.",
"Step 1 failed. Exception: %s" => "L’étape 1 a échoué. Erreur : %s",
"Step 2 failed. Exception: %s" => "L’étape 2 a échoué. Erreur : %s",
"External storage" => "Stockage externe",
"Local" => "Local",
"Location" => "Emplacement",
"Amazon S3" => "Amazon S3",
"Key" => "Clé",
"Secret" => "Secret",
"Bucket" => "Seau",
"Amazon S3 and compliant" => "Compatible avec Amazon S3",
"Access Key" => "Clé d'accès",
"Secret Key" => "Clé secrète",
"Hostname (optional)" => "Nom machine (optionnel)",
"Port (optional)" => "Port (optionnel)",
"Region (optional)" => "Région (facultatif)",
"Enable SSL" => "Activer SSL",
"Enable Path Style" => "Activer le style de chemin",
"App key" => "Clé App",
"App secret" => "Secret de l'application",
"Host" => "Hôte",
"Username" => "Nom d'utilisateur",
"Password" => "Mot de passe",
"Root" => "Root",
"Secure ftps://" => "Sécurisation ftps://",
"Client ID" => "ID Client",
"Client secret" => "Secret client",
"OpenStack Object Storage" => "Object de Stockage OpenStack",
"Username (required)" => "Nom d'utilisation (requis)",
"Bucket (required)" => "Bucket (requis)",
"Region (optional for OpenStack Object Storage)" => "Region (optionnel pour Object de Stockage OpenStack)",
"API Key (required for Rackspace Cloud Files)" => "Clé API (requis pour Rackspace Cloud Files)",
"Tenantname (required for OpenStack Object Storage)" => "Nom du locataire (requis pour le stockage OpenStack)",
"Password (required for OpenStack Object Storage)" => "Mot de passe (requis pour OpenStack Object Storage)",
"Service Name (required for OpenStack Object Storage)" => "Nom du service (requit pour le stockage OpenStack)",
"URL of identity endpoint (required for OpenStack Object Storage)" => "URL du point d'accès d'identité (requis pour le stockage OpenStack)",
"Timeout of HTTP requests in seconds (optional)" => "Temps maximal de requête HTTP en seconde (facultatif)",
"Share" => "Partager",
"SMB / CIFS using OC login" => "SMB / CIFS en utilisant les identifiants OC",
"Username as share" => "Nom d'utilisateur du partage",
"URL" => "URL",
"Secure https://" => "Sécurisation https://",
"Remote subfolder" => "Sous-dossier distant",
"Access granted" => "Accès autorisé",
"Error configuring Dropbox storage" => "Erreur lors de la configuration du support de stockage Dropbox",
"Grant access" => "Autoriser l'accès",
"Error configuring Google Drive storage" => "Erreur lors de la configuration du support de stockage Google Drive",
"Personal" => "Personnel",
"System" => "Système",
"Saved" => "Sauvegarder",
"<b>Note:</b> " => "<b>Attention :</b>",
" and " => "et",
"<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." => "<b>Attention :</b> La prise en charge de cURL par PHP n'est pas activée ou installée. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
"<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." => "<b>Attention : </b> La prise en charge du FTP par PHP n'est pas activée ou installée. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
"<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." => "<b>Attention : </b> \"%s\" n'est pas installé. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
"You don't have any external storages" => "Vous n'avez pas de support de stockage externe",
"Name" => "Nom",
"Storage type" => "Type de support de stockage",
"Scope" => "Portée",
"External Storage" => "Stockage externe",
"Folder name" => "Nom du dossier",
"Configuration" => "Configuration",
"Options" => "Options",
"Available for" => "Disponible pour",
"Add storage" => "Ajouter un support de stockage",
"No user or group" => "Aucun utilisateur ou groupe",
"All Users" => "Tous les utilisateurs",
"Groups" => "Groupes",
"Users" => "Utilisateurs",
"Delete" => "Supprimer",
"Enable User External Storage" => "Autoriser les utilisateurs à ajouter des stockages externes",
"Allow users to mount the following external storage" => "Autorise les utilisateurs à monter les stockage externes suivants",
"SSL root certificates" => "Certificats racine SSL",
"Import Root Certificate" => "Importer un certificat racine"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
